<template>
  <div class="app-container">
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="Download"
          @click="handleExport"
          v-hasPermi="['abnormalAnalysis:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :search="false" @refreshTable="getList"></right-toolbar>
    </el-row>
    <HxlhTable
        style="width: 100%"
        :columns="columns"
        :data="dataList"
        :loading="loading"
        :height="height"  ></HxlhTable>

  </div>
</template>

<script setup name="ApsAbnormalProcessAnalysis">
import { list } from "@/api/mainPlan/abnormalProcessAnalysis";
import HxlhTable from '@/components/HxlhTable/index.vue'
import { ref } from "vue";
import { getToken } from "@/utils/auth.js";
// import { ElMessage} from "element-plus";

const { proxy } = getCurrentInstance();

const dataList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");
const height = ref(document.documentElement.clientHeight - 160 + "px;")

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    processName: null,
    source: null,
    summary: null,
  },
  rules: {
  }
});

const { queryParams, form, rules } = toRefs(data);
const columns = ref([
  { type: 'seq', title: '序号', width: 60 },
  { title: '工序名称',  field: 'processName'},
  { title: '异常来源',  field: 'source'},
  { title: '异常描述',  field: 'summary'},
  { title: '创建时间',  field: 'createTime',  width: 200},
])

/** 查询工序异常分析列表 */
function getList() {
  loading.value = true;
  list(queryParams.value).then(response => {
    dataList.value = response.rows;
    total.value = response.total;
    loading.value = false;
  });
}


/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}
/** 导出按钮操作 */
function handleExport() {
  proxy.download('aps/abnormalProcessAnalysis/export', {
    ...queryParams.value
  }, `AbnormalProcessAnalysis_${new Date().getTime()}.xlsx`)
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加工序异常分析";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const _id = row.id || ids.value
  getApsAbnormalProcessAnalysis(_id).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改工序异常分析";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["ApsAbnormalProcessAnalysisRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updateApsAbnormalProcessAnalysis(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addApsAbnormalProcessAnalysis(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const _ids = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除工序异常分析编号为"' + _ids + '"的数据项？').then(function() {
    return delApsAbnormalProcessAnalysis(_ids);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}


// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    processName: null,
    source: null,
    summary: null,
    createTime: null,
    delFlag: null,
    createBy: null
  };
  proxy.resetForm("ApsAbnormalProcessAnalysisRef");
}

getList();
</script>
